========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/neutron-lbaas.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

.. warning::
   Neutron-lbaas is now deprecated. Please see the FAQ: https://wiki.openstack.org/wiki/Neutron/LBaaS/Deprecation

Welcome!
========

This package contains the code for the Neutron Load Balancer as a
Service (LBaaS) service. This includes third-party drivers. This package
requires Neutron to run.

External Resources:
===================

The homepage for Octavia LBaaS is: https://launchpad.net/octavia.  Use this
site for asking for help, and filing bugs.

Code is available on git.openstack.org at:
<http://git.openstack.org/cgit/openstack/neutron-lbaas>.

Please refer to Neutron documentation for more information:
`Neutron README.rst <http://git.openstack.org/cgit/openstack/neutron/tree/README.rst>`_

Release notes for the project can be found at:
<https://docs.openstack.org/releasenotes/neutron-lbaas/index.html>.
